Chapter 2: Lens Modeling
========================

In chapter 2, we'll take you through how to model galaxies using a non-linear search.

The chapter contains the following tutorials:

`Tutorial 1: Non Linear Search <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_1_non_linear_search.ipynb>`_
- How a non-linear search is used to fit a galaxy model.

`Tutorial 2: Parameter Space And Priors <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_2_parameter_space_and_priors.ipynb>`_
- The Concepts of a parameter space and priors.

`Tutorial 3: Realism and Complexity <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_3_realism_and_complexity.ipynb>`_
- Finding a balance between realism and complexity when composing and fitting a model.

`Tutorial 4: Dealing with Failure <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_4_dealing_with_failure.ipynb>`_
- What to do when PyAutoGalaxy finds an inaccurate model.

`Tutorial 5: Masking and Positions <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_5_masking.ipynb>`_
- How to mask your data to improve the model.

`Tutorial 6: Results <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_6_results.ipynb>`_
- Overview of the results available after successfully fitting a model.

`Tutorial 7: Need for Speed <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_7_need_for_speed.ipynb>`_
- How to fit complex models whilst balancing efficiency and run-time.
